"""Tests for NERFileMorphosyntacticDictionary."""

from tempfile import NamedTemporaryFile

from src.detections import NameDetection, SurnameDetection
from src.dictionaries.morphosyntactic.ner_file import NERFileMorphosyntacticDictionary


def test_ner_file_morphosyntactic_dictionary():
    """Test NERFileMorphosyntacticDictionary."""
    with NamedTemporaryFile() as file:
        file.writelines(
            [
                "name	Andrzejowi	Andrzej	a\n".encode("utf-8"),
                "name	Andrzej	Andrzej	b\n".encode("utf-8"),
                "name	Kasia	Kasia	c\n".encode("utf-8"),
                "city	Wrocław	Wrocław	d\n".encode("utf-8"),
                "city	Warszawa	Warszawa	c\n".encode("utf-8"),
                "city	Kraków	Kraków	d\n".encode("utf-8"),
            ]
        )
        file.flush()

        dictionary = NERFileMorphosyntacticDictionary(file.name)

        example_name_1 = NameDetection(morpho_tag="a", lemma="Andrzej")
        example_name_2 = NameDetection(morpho_tag="b", lemma="Andrzej")
        example_name_3 = NameDetection(morpho_tag="c", lemma="Andrzej")
        example_other = SurnameDetection(morpho_tag="c", lemma="Kowalski")

        assert dictionary.get_random_replacement(example_name_1) == {
            "lemma": "Andrzej",
            "tag": "a",
            "type": "name",
            "word": "Andrzejowi",
        }
        assert dictionary.get_random_replacement(example_name_2) == {
            "lemma": "Andrzej",
            "tag": "b",
            "type": "name",
            "word": "Andrzej",
        }

        # If no good replacement is present, it should choose a random one
        assert dictionary.get_random_replacement(example_other)["word"] in [
            "Andrzejowi",
            "Andrzej",
            "Kasia",
            "Wrocław",
            "Warszawa",
            "Kraków",
        ]

        # It should return replacements that have required tags
        random_replacements = dictionary.get_random_replacements(
            [example_name_1, example_name_2]
        )
        for replacement in random_replacements:
            assert replacement["word"] in ["Andrzejowi", "Andrzej"]
            assert replacement["lemma"] == "Andrzej"

        # It should resort to random replacements if no good ones are present
        random_replacements = dictionary.get_random_replacements(
            [example_name_1, example_name_2, example_name_3]
        )
        for replacement in random_replacements:
            assert replacement["word"] in [
                "Andrzejowi",
                "Andrzej",
                "Kasia",
                "Wrocław",
                "Warszawa",
                "Kraków",
            ]
