"""Tests for sequential jsonl pipeline."""

from tempfile import NamedTemporaryFile

from src.detections import NameDetection
from src.detectors.interface import Detector
from src.input_parsers.interface import InputParser
from src.pipeline.sequential_jsonl import SequentialJSONLPipeline
from src.replacers.interface import ReplacerInterface
from src.suppressors.interface import Suppressor


class _MockInputParser(InputParser):
    def parse(self, content):
        return "ala ma kota", {}


class _MockDetector(Detector):
    def detect(self, text, annotations):
        return [(0, 3, NameDetection("morpho_tag"))]


class _MockSuppressor(Suppressor):
    def suppress(self, annotations):
        return annotations


class _MockReplacer(ReplacerInterface):
    def replace(self, text, annotations):
        return "zbigniew ma kota", annotations


def test_sequential_jsonl_pipeline():
    """Test sequential jsonl pipeline."""
    # TODO: Prepare mocks that will better test the pipeline
    pipeline = SequentialJSONLPipeline(
        _MockInputParser(),
        {"mock_detector": _MockDetector()},
        _MockSuppressor(),
        {"mock_replacer": _MockReplacer()},
    )

    with NamedTemporaryFile() as f:
        f.write(b'{"text": "ala ma kota"}\n{"text": "ala ma kota"}')
        f.flush()
        result = pipeline.run(f.name)

        assert result == '{"text": "zbigniew ma kota"}\n{"text": "zbigniew ma kota"}'
