"""Tests for email replacer."""

from src.detections import CityDetection, DateDetection, EmailDetection
from src.replacers.email_replacer import EmailReplacer


def test_email_replacer():
    """Test email replacer."""
    text = "zz@z.pl urodziła sie 05.05.2005 we Wrocławiu"
    detections = [
        (0, 7, EmailDetection()),
        (21, 31, DateDetection()),
        (35, 44, CityDetection("subst:sg:loc:m3")),
    ]

    replacer = EmailReplacer()
    result = replacer.replace(text, detections)

    expected_text_ending = " urodziła sie 05.05.2005 we Wrocławiu"
    exptected_detections_left = [
        (len(result[0]) - 23, len(result[0]) - 13, DateDetection()),
        (len(result[0]) - 9, len(result[0]), CityDetection("subst:sg:loc:m3")),
    ]

    assert result[0].endswith(expected_text_ending)
    assert result[0][0 : -len(expected_text_ending)] != "zz@z.pl"
    assert result[1] == exptected_detections_left


def test_email_replacer_same_email_same_replacement():
    """Test to make sure that the same emails are replaced in the same way."""
    text = "zz@z.pl zz@z.pl aa@a.pl"
    detections = [
        (0, 7, EmailDetection()),
        (8, 15, EmailDetection()),
        (16, 22, EmailDetection()),
    ]

    replacer = EmailReplacer()
    result = replacer.replace(text, detections)

    old_emails = text.split()
    new_emails = result[0].split()

    assert old_emails[0] != new_emails[0]
    assert new_emails[0] == new_emails[1]
    assert result[1] == []
